@@ -4,7 +4,6 @@ from copy import deepcopy
 from .algorithm import Algorithm
 from .operators import RandomGenerator, SimulatedBinaryCrossover, \
     PmMutator, TournamentSelector, EpsilonDominance, nondominated_truncate, crowding_distance
-from .population import Population
 from .problem import Problem
 from .archive import Archive
 
@@ -112,7 +111,6 @@ class NSGAII(GeneticAlgorithm):
                              desc='prob_mutation')
 
         # set random generator
-        self.individual_features = dict()
         self.individual_features['dominate'] = set()
         self.individual_features['crowding_distance'] = 0
         self.individual_features['domination_counter'] = 0
@@ -203,7 +201,6 @@ class EpsMOEA(GeneticAlgorithm):
         self.archive = None
 
         # set random generator
-        self.individual_features = dict()
         self.individual_features['dominate'] = set()
         self.individual_features['crowding_distance'] = 0
         self.individual_features['domination_counter'] = 0
