@@ -1,6 +1,5 @@
 from random import randint, random, uniform, choice
 from .problem import Problem
-from .population import Population
 from .algorithm_genetic import GeneralEvolutionaryAlgorithm
 from .operators import RandomGenerator, PmMutator, ParetoDominance, EpsilonDominance, crowding_distance, \
     NonUniformMutation, UniformMutator, CopySelector
@@ -121,7 +120,6 @@ class OMOPSO(SwarmAlgorithm):
         self.selector = CopySelector(self.problem.parameters)
         self.dominance = ParetoDominance()
 
-        self.individual_features = dict()
         self.individual_features['velocity'] = dict()
         self.individual_features['best_cost'] = dict()
         self.individual_features['best_vector'] = dict()
